]> ruderich.org/simon Gitweb - config/dotfiles.git/blobdiff - sync.sh
Fix leaking a variable in lib.sh.
[config/dotfiles.git] / sync.sh
diff --git a/sync.sh b/sync.sh
index 6477d0d9a01c39778a7da9042654baf9a25980d2..e76ce8e55a149d9af664291dfc6032f9fb06f8fb 100755 (executable)
--- a/sync.sh
+++ b/sync.sh
@@ -5,29 +5,49 @@
 # Allows fetching (no merge) and pushing at the moment.
 
 
# Select the method, fetch and push is possible.
 if [ x$1 = x -o x$1 = xfetch -o x$1 = xfe ]; then
     method=fetch
 elif [ $1 = push -o $1 = pu ]; then
     method=push
+elif [ $1 = status -o $1 = st ]; then
+    method=status
 else
-    echo "Usage: sync.sh [fetch | fe | push | pu ]"
+    echo "Usage: sync.sh [fetch | fe | push | pu | status | st]"
     echo
     echo "fetch: Fetch from all remotes."
     echo "push: Push to all remotes."
+    echo "status: Display status for all git repositories."
     exit 1
 fi
 
-# Fetch from/Push to each remote of each git subdirectory.
+# Execute the given method for each git subdirectory.
 for project in `find . -name .git -type d`; do
     pwd=`pwd`
     cd "$project"
 
+    # Remove .git from repository name.
+    project=`echo "$project" | sed "s|.git||"`
+
+    # Display all commits not in the master branch.
+    if [ $method = status ]; then
+        output=`git log --graph --all --pretty=oneline --color master..`
+        if [ "x$output" != x ]; then
+            echo "$project status:"
+            echo "$output"
+        fi
     # Fetch from/Push to all remotes.
-    for remote in `git remote`; do
-        echo "$project: ${method}ing $remote ..."
-        git $method "$remote"
-    done
+    else
+        for remote in `git remote`; do
+            echo "$project: ${method}ing $remote ..."
+            git $method "$remote"
+        done
+    fi
 
     cd "$pwd"
 done
+
+# Run status after a fetch to see new changes.
+if [ $method = fetch ]; then
+    ./sync.sh status
+fi
@@ -5,29 +5,49 @@
 
 
-# Select the method, fetch and push is possible.
+# Select the method: fetch, push and status is possible.
 if [ x$1 = x -o x$1 = xfetch -o x$1 = xfe ]; then
     method=fetch